==> ejc-budgetmanage-impl-3.0.0-20220406.092419-64-sources.jar: com/ejianc/business/bedget/bean/SubpackagedetailEntity.java <==
package com.ejianc.business.bedget.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包施工图预算子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_budgetmanage_subpackagedetail")
public class SubpackagedetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="tid")
    private java.lang.String tid;
    @TableField(value="tpid")
    private java.lang.String tpid;
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="section")
    private java.lang.String section; // 区段
    @TableField(value="subtitle_code")
    private java.lang.String subtitleCode; // 子目编码
    @TableField(value="subtitle_name")
    private java.lang.String subtitleName; // 子目名称
    @TableField(value="subtitle_feature")
    private java.lang.String subtitleFeature; // 子目特征描述
    @TableField(value="measuring_unit")
    private java.lang.String measuringUnit; // 计量单位
    @TableField(value="quantities")
    private java.math.BigDecimal quantities; // 工程量
    @TableField(value="artificial_unit_price")
    private java.math.BigDecimal artificialUnitPrice; // 人工费
    @TableField(value="materials_unit_price")
    private java.math.BigDecimal materialsUnitPrice; // 材料费
    @TableField(value="mechanical_unit_price")
    private java.math.BigDecimal mechanicalUnitPrice; // 机械费
    @TableField(value="enterprise_manage_unit_price")
    private java.math.BigDecimal enterpriseManageUnitPrice; // 企业管理费
    @TableField(value="profits_unit_price")
    private java.math.BigDecimal profitsUnitPrice; // 利润
    @TableField(value="fees_unit_price")
    private java.math.BigDecimal feesUnitPrice; // 规费
    @TableField(value="tax_unit_price")
    private java.math.BigDecimal taxUnitPrice; // 税金
    @TableField(value="comprehensive_unit_price")
    private java.math.BigDecimal comprehensiveUnitPrice; // 综合单价
    @TableField(value="artificial_total")
    private java.math.BigDecimal artificialTotal; // 人工费
    @TableField(value="materials_total")
    private java.math.BigDecimal materialsTotal; // 材料费
    @TableField(value="mechanical_total")
    private java.math.BigDecimal mechanicalTotal; // 机械费
    @TableField(value="enterprise_manage_total")
    private java.math.BigDecimal enterpriseManageTotal; // 企业管理费
    @TableField(value="profits_total")
    private java.math.BigDecimal profitsTotal; // 利润
    @TableField(value="fees_total")
    private java.math.BigDecimal feesTotal; // 规费
    @TableField(value="tax_total")
    private java.math.BigDecimal taxTotal; // 税金
    @TableField(value="comprehensive_total")
    private java.math.BigDecimal comprehensiveTotal; // 合价（元）
    @TableField(value="subpackage_budget_total")
    private java.math.BigDecimal subpackageBudgetTotal; // 分包施工图预算量合计
    @TableField(value="subpackage_quantities")
    private java.math.BigDecimal subpackageQuantities; // 工程量
    @TableField(value="subpackage_measuring_unit")
    private java.lang.String subpackageMeasuringUnit; // 计量单位
    @TableField(value="excluding_tax_unit_price")
    private java.math.BigDecimal excludingTaxUnitPrice; // 除税单价
    @TableField(value="including_tax_unit_price")
    private java.math.BigDecimal includingTaxUnitPrice; // 含税单价
    @TableField(value="excluding_tax_total")
    private java.math.BigDecimal excludingTaxTotal; // 除税合价
    @TableField(value="including_tax_total")
    private java.math.BigDecimal includingTaxTotal; // 含税合价


    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    /**
     * 区段
     */
    public java.lang.String getSection() {
        return section;
    }

    /**
     * 区段
     */
    public void setSection(java.lang.String section) {
        this.section = section;
    }
    /**
     * 子目编码
     */
    public java.lang.String getSubtitleCode() {
        return subtitleCode;
    }

    /**
     * 子目编码
     */
    public void setSubtitleCode(java.lang.String subtitleCode) {
        this.subtitleCode = subtitleCode;
    }
    /**
     * 子目名称
     */
    public java.lang.String getSubtitleName() {
        return subtitleName;
    }

    /**
     * 子目名称
     */
    public void setSubtitleName(java.lang.String subtitleName) {
        this.subtitleName = subtitleName;
    }
    /**
     * 子目特征描述
     */
    public java.lang.String getSubtitleFeature() {
        return subtitleFeature;
    }

    /**
     * 子目特征描述
     */
    public void setSubtitleFeature(java.lang.String subtitleFeature) {
        this.subtitleFeature = subtitleFeature;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }
    /**
     * 工程量
     */
    public java.math.BigDecimal getQuantities() {
        return quantities;
    }

    /**
     * 工程量
     */
    public void setQuantities(java.math.BigDecimal quantities) {
        this.quantities = quantities;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getArtificialUnitPrice() {
        return artificialUnitPrice;
    }

    /**
     * 人工费
     */
    public void setArtificialUnitPrice(java.math.BigDecimal artificialUnitPrice) {
        this.artificialUnitPrice = artificialUnitPrice;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialsUnitPrice() {
        return materialsUnitPrice;
    }

    /**
     * 材料费
     */
    public void setMaterialsUnitPrice(java.math.BigDecimal materialsUnitPrice) {
        this.materialsUnitPrice = materialsUnitPrice;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMechanicalUnitPrice() {
        return mechanicalUnitPrice;
    }

    /**
     * 机械费
     */
    public void setMechanicalUnitPrice(java.math.BigDecimal mechanicalUnitPrice) {
        this.mechanicalUnitPrice = mechanicalUnitPrice;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getEnterpriseManageUnitPrice() {
        return enterpriseManageUnitPrice;
    }

    /**
     * 企业管理费
     */
    public void setEnterpriseManageUnitPrice(java.math.BigDecimal enterpriseManageUnitPrice) {
        this.enterpriseManageUnitPrice = enterpriseManageUnitPrice;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfitsUnitPrice() {
        return profitsUnitPrice;
    }

    /**
     * 利润
     */
    public void setProfitsUnitPrice(java.math.BigDecimal profitsUnitPrice) {
        this.profitsUnitPrice = profitsUnitPrice;
    }
    /**
     * 规费
     */
    public java.math.BigDecimal getFeesUnitPrice() {
        return feesUnitPrice;
    }

    /**
     * 规费
     */
    public void setFeesUnitPrice(java.math.BigDecimal feesUnitPrice) {
        this.feesUnitPrice = feesUnitPrice;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTaxUnitPrice() {
        return taxUnitPrice;
    }

    /**
     * 税金
     */
    public void setTaxUnitPrice(java.math.BigDecimal taxUnitPrice) {
        this.taxUnitPrice = taxUnitPrice;
    }
    /**
     * 综合单价
     */
    public java.math.BigDecimal getComprehensiveUnitPrice() {
        return comprehensiveUnitPrice;
    }

    /**
     * 综合单价
     */
    public void setComprehensiveUnitPrice(java.math.BigDecimal comprehensiveUnitPrice) {
        this.comprehensiveUnitPrice = comprehensiveUnitPrice;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getArtificialTotal() {
        return artificialTotal;
    }

    /**
     * 人工费
     */
    public void setArtificialTotal(java.math.BigDecimal artificialTotal) {
        this.artificialTotal = artificialTotal;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialsTotal() {
        return materialsTotal;
    }

    /**
     * 材料费
     */
    public void setMaterialsTotal(java.math.BigDecimal materialsTotal) {
        this.materialsTotal = materialsTotal;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMechanicalTotal() {
        return mechanicalTotal;
    }

    /**
     * 机械费
     */
    public void setMechanicalTotal(java.math.BigDecimal mechanicalTotal) {
        this.mechanicalTotal = mechanicalTotal;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getEnterpriseManageTotal() {
        return enterpriseManageTotal;
    }

    /**
     * 企业管理费
     */
    public void setEnterpriseManageTotal(java.math.BigDecimal enterpriseManageTotal) {
        this.enterpriseManageTotal = enterpriseManageTotal;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfitsTotal() {
        return profitsTotal;
    }

    /**
     * 利润
     */
    public void setProfitsTotal(java.math.BigDecimal profitsTotal) {
        this.profitsTotal = profitsTotal;
    }
    /**
     * 规费
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 合价（元）
     */
    public java.math.BigDecimal getComprehensiveTotal() {
        return comprehensiveTotal;
    }

    /**
     * 合价（元）
     */
    public void setComprehensiveTotal(java.math.BigDecimal comprehensiveTotal) {
        this.comprehensiveTotal = comprehensiveTotal;
    }
    /**
     * 分包施工图预算量合计
     */
    public java.math.BigDecimal getSubpackageBudgetTotal() {
        return subpackageBudgetTotal;
    }

    /**
     * 分包施工图预算量合计
     */
    public void setSubpackageBudgetTotal(java.math.BigDecimal subpackageBudgetTotal) {
        this.subpackageBudgetTotal = subpackageBudgetTotal;
    }
    /**
     * 工程量
     */
    public java.math.BigDecimal getSubpackageQuantities() {
        return subpackageQuantities;
    }

    /**
     * 工程量
     */
    public void setSubpackageQuantities(java.math.BigDecimal subpackageQuantities) {
        this.subpackageQuantities = subpackageQuantities;
    }
    /**
     * 计量单位
     */
    public java.lang.String getSubpackageMeasuringUnit() {
        return subpackageMeasuringUnit;
    }

    /**
     * 计量单位
     */
    public void setSubpackageMeasuringUnit(java.lang.String subpackageMeasuringUnit) {
        this.subpackageMeasuringUnit = subpackageMeasuringUnit;
    }
    /**
     * 除税单价
     */
    public java.math.BigDecimal getExcludingTaxUnitPrice() {
        return excludingTaxUnitPrice;
    }

    /**
     * 除税单价
     */
    public void setExcludingTaxUnitPrice(java.math.BigDecimal excludingTaxUnitPrice) {
        this.excludingTaxUnitPrice = excludingTaxUnitPrice;
    }
    /**
     * 含税单价
     */
    public java.math.BigDecimal getIncludingTaxUnitPrice() {
        return includingTaxUnitPrice;
    }

    /**
     * 含税单价
     */
    public void setIncludingTaxUnitPrice(java.math.BigDecimal includingTaxUnitPrice) {
        this.includingTaxUnitPrice = includingTaxUnitPrice;
    }
    /**
     * 除税合价
     */
    public java.math.BigDecimal getExcludingTaxTotal() {
        return excludingTaxTotal;
    }

    /**
     * 除税合价
     */
    public void setExcludingTaxTotal(java.math.BigDecimal excludingTaxTotal) {
        this.excludingTaxTotal = excludingTaxTotal;
    }
    /**
     * 含税合价
     */
    public java.math.BigDecimal getIncludingTaxTotal() {
        return includingTaxTotal;
    }

    /**
     * 含税合价
     */
    public void setIncludingTaxTotal(java.math.BigDecimal includingTaxTotal) {
        this.includingTaxTotal = includingTaxTotal;
    }
    
}

==> ejc-budgetmanage-impl-3.0.0-20230324.091733-161-sources.jar: com/ejianc/business/bedget/bean/SubpackagedetailEntity.java <==
package com.ejianc.business.bedget.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包施工图预算子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_budgetmanage_subpackagedetail")
public class SubpackagedetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="tid")
    private java.lang.String tid;
    @TableField(value="tpid")
    private java.lang.String tpid;
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="section")
    private java.lang.String section; // 区段
    @TableField(value="subtitle_code")
    private java.lang.String subtitleCode; // 子目编码
    @TableField(value="subtitle_name")
    private java.lang.String subtitleName; // 子目名称
    @TableField(value="subtitle_feature")
    private java.lang.String subtitleFeature; // 子目特征描述
    @TableField(value="measuring_unit")
    private java.lang.String measuringUnit; // 计量单位
    @TableField(value="quantities")
    private java.math.BigDecimal quantities; // 工程量
    @TableField(value="artificial_unit_price")
    private java.math.BigDecimal artificialUnitPrice; // 人工费
    @TableField(value="materials_unit_price")
    private java.math.BigDecimal materialsUnitPrice; // 材料费
    @TableField(value="mechanical_unit_price")
    private java.math.BigDecimal mechanicalUnitPrice; // 机械费
    @TableField(value="enterprise_manage_unit_price")
    private java.math.BigDecimal enterpriseManageUnitPrice; // 企业管理费
    @TableField(value="profits_unit_price")
    private java.math.BigDecimal profitsUnitPrice; // 利润
    @TableField(value="fees_unit_price")
    private java.math.BigDecimal feesUnitPrice; // 规费
    @TableField(value="tax_unit_price")
    private java.math.BigDecimal taxUnitPrice; // 税金
    @TableField(value="comprehensive_unit_price")
    private java.math.BigDecimal comprehensiveUnitPrice; // 综合单价
    @TableField(value="artificial_total")
    private java.math.BigDecimal artificialTotal; // 人工费
    @TableField(value="materials_total")
    private java.math.BigDecimal materialsTotal; // 材料费
    @TableField(value="mechanical_total")
    private java.math.BigDecimal mechanicalTotal; // 机械费
    @TableField(value="enterprise_manage_total")
    private java.math.BigDecimal enterpriseManageTotal; // 企业管理费
    @TableField(value="profits_total")
    private java.math.BigDecimal profitsTotal; // 利润
    @TableField(value="fees_total")
    private java.math.BigDecimal feesTotal; // 规费
    @TableField(value="tax_total")
    private java.math.BigDecimal taxTotal; // 税金
    @TableField(value="comprehensive_total")
    private java.math.BigDecimal comprehensiveTotal; // 合价（元）
    @TableField(value="subpackage_budget_total")
    private java.math.BigDecimal subpackageBudgetTotal; // 分包施工图预算量合计
    @TableField(value="subpackage_quantities")
    private java.math.BigDecimal subpackageQuantities; // 工程量
    @TableField(value="subpackage_measuring_unit")
    private java.lang.String subpackageMeasuringUnit; // 计量单位
    @TableField(value="excluding_tax_unit_price")
    private java.math.BigDecimal excludingTaxUnitPrice; // 除税单价
    @TableField(value="including_tax_unit_price")
    private java.math.BigDecimal includingTaxUnitPrice; // 含税单价
    @TableField(value="excluding_tax_total")
    private java.math.BigDecimal excludingTaxTotal; // 除税合价
    @TableField(value="including_tax_total")
    private java.math.BigDecimal includingTaxTotal; // 含税合价
    @TableField(value="consdrawbudget_id")
    private java.lang.Long consdrawbudgetId; // 施工图预算子表行ID


    public Long getConsdrawbudgetId() {
        return consdrawbudgetId;
    }

    public void setConsdrawbudgetId(Long consdrawbudgetId) {
        this.consdrawbudgetId = consdrawbudgetId;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    /**
     * 区段
     */
    public java.lang.String getSection() {
        return section;
    }

    /**
     * 区段
     */
    public void setSection(java.lang.String section) {
        this.section = section;
    }
    /**
     * 子目编码
     */
    public java.lang.String getSubtitleCode() {
        return subtitleCode;
    }

    /**
     * 子目编码
     */
    public void setSubtitleCode(java.lang.String subtitleCode) {
        this.subtitleCode = subtitleCode;
    }
    /**
     * 子目名称
     */
    public java.lang.String getSubtitleName() {
        return subtitleName;
    }

    /**
     * 子目名称
     */
    public void setSubtitleName(java.lang.String subtitleName) {
        this.subtitleName = subtitleName;
    }
    /**
     * 子目特征描述
     */
    public java.lang.String getSubtitleFeature() {
        return subtitleFeature;
    }

    /**
     * 子目特征描述
     */
    public void setSubtitleFeature(java.lang.String subtitleFeature) {
        this.subtitleFeature = subtitleFeature;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }
    /**
     * 工程量
     */
    public java.math.BigDecimal getQuantities() {
        return quantities;
    }

    /**
     * 工程量
     */
    public void setQuantities(java.math.BigDecimal quantities) {
        this.quantities = quantities;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getArtificialUnitPrice() {
        return artificialUnitPrice;
    }

    /**
     * 人工费
     */
    public void setArtificialUnitPrice(java.math.BigDecimal artificialUnitPrice) {
        this.artificialUnitPrice = artificialUnitPrice;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialsUnitPrice() {
        return materialsUnitPrice;
    }

    /**
     * 材料费
     */
    public void setMaterialsUnitPrice(java.math.BigDecimal materialsUnitPrice) {
        this.materialsUnitPrice = materialsUnitPrice;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMechanicalUnitPrice() {
        return mechanicalUnitPrice;
    }

    /**
     * 机械费
     */
    public void setMechanicalUnitPrice(java.math.BigDecimal mechanicalUnitPrice) {
        this.mechanicalUnitPrice = mechanicalUnitPrice;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getEnterpriseManageUnitPrice() {
        return enterpriseManageUnitPrice;
    }

    /**
     * 企业管理费
     */
    public void setEnterpriseManageUnitPrice(java.math.BigDecimal enterpriseManageUnitPrice) {
        this.enterpriseManageUnitPrice = enterpriseManageUnitPrice;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfitsUnitPrice() {
        return profitsUnitPrice;
    }

    /**
     * 利润
     */
    public void setProfitsUnitPrice(java.math.BigDecimal profitsUnitPrice) {
        this.profitsUnitPrice = profitsUnitPrice;
    }
    /**
     * 规费
     */
    public java.math.BigDecimal getFeesUnitPrice() {
        return feesUnitPrice;
    }

    /**
     * 规费
     */
    public void setFeesUnitPrice(java.math.BigDecimal feesUnitPrice) {
        this.feesUnitPrice = feesUnitPrice;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTaxUnitPrice() {
        return taxUnitPrice;
    }

    /**
     * 税金
     */
    public void setTaxUnitPrice(java.math.BigDecimal taxUnitPrice) {
        this.taxUnitPrice = taxUnitPrice;
    }
    /**
     * 综合单价
     */
    public java.math.BigDecimal getComprehensiveUnitPrice() {
        return comprehensiveUnitPrice;
    }

    /**
     * 综合单价
     */
    public void setComprehensiveUnitPrice(java.math.BigDecimal comprehensiveUnitPrice) {
        this.comprehensiveUnitPrice = comprehensiveUnitPrice;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getArtificialTotal() {
        return artificialTotal;
    }

    /**
     * 人工费
     */
    public void setArtificialTotal(java.math.BigDecimal artificialTotal) {
        this.artificialTotal = artificialTotal;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialsTotal() {
        return materialsTotal;
    }

    /**
     * 材料费
     */
    public void setMaterialsTotal(java.math.BigDecimal materialsTotal) {
        this.materialsTotal = materialsTotal;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMechanicalTotal() {
        return mechanicalTotal;
    }

    /**
     * 机械费
     */
    public void setMechanicalTotal(java.math.BigDecimal mechanicalTotal) {
        this.mechanicalTotal = mechanicalTotal;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getEnterpriseManageTotal() {
        return enterpriseManageTotal;
    }

    /**
     * 企业管理费
     */
    public void setEnterpriseManageTotal(java.math.BigDecimal enterpriseManageTotal) {
        this.enterpriseManageTotal = enterpriseManageTotal;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfitsTotal() {
        return profitsTotal;
    }

    /**
     * 利润
     */
    public void setProfitsTotal(java.math.BigDecimal profitsTotal) {
        this.profitsTotal = profitsTotal;
    }
    /**
     * 规费
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 合价（元）
     */
    public java.math.BigDecimal getComprehensiveTotal() {
        return comprehensiveTotal;
    }

    /**
     * 合价（元）
     */
    public void setComprehensiveTotal(java.math.BigDecimal comprehensiveTotal) {
        this.comprehensiveTotal = comprehensiveTotal;
    }
    /**
     * 分包施工图预算量合计
     */
    public java.math.BigDecimal getSubpackageBudgetTotal() {
        return subpackageBudgetTotal;
    }

    /**
     * 分包施工图预算量合计
     */
    public void setSubpackageBudgetTotal(java.math.BigDecimal subpackageBudgetTotal) {
        this.subpackageBudgetTotal = subpackageBudgetTotal;
    }
    /**
     * 工程量
     */
    public java.math.BigDecimal getSubpackageQuantities() {
        return subpackageQuantities;
    }

    /**
     * 工程量
     */
    public void setSubpackageQuantities(java.math.BigDecimal subpackageQuantities) {
        this.subpackageQuantities = subpackageQuantities;
    }
    /**
     * 计量单位
     */
    public java.lang.String getSubpackageMeasuringUnit() {
        return subpackageMeasuringUnit;
    }

    /**
     * 计量单位
     */
    public void setSubpackageMeasuringUnit(java.lang.String subpackageMeasuringUnit) {
        this.subpackageMeasuringUnit = subpackageMeasuringUnit;
    }
    /**
     * 除税单价
     */
    public java.math.BigDecimal getExcludingTaxUnitPrice() {
        return excludingTaxUnitPrice;
    }

    /**
     * 除税单价
     */
    public void setExcludingTaxUnitPrice(java.math.BigDecimal excludingTaxUnitPrice) {
        this.excludingTaxUnitPrice = excludingTaxUnitPrice;
    }
    /**
     * 含税单价
     */
    public java.math.BigDecimal getIncludingTaxUnitPrice() {
        return includingTaxUnitPrice;
    }

    /**
     * 含税单价
     */
    public void setIncludingTaxUnitPrice(java.math.BigDecimal includingTaxUnitPrice) {
        this.includingTaxUnitPrice = includingTaxUnitPrice;
    }
    /**
     * 除税合价
     */
    public java.math.BigDecimal getExcludingTaxTotal() {
        return excludingTaxTotal;
    }

    /**
     * 除税合价
     */
    public void setExcludingTaxTotal(java.math.BigDecimal excludingTaxTotal) {
        this.excludingTaxTotal = excludingTaxTotal;
    }
    /**
     * 含税合价
     */
    public java.math.BigDecimal getIncludingTaxTotal() {
        return includingTaxTotal;
    }

    /**
     * 含税合价
     */
    public void setIncludingTaxTotal(java.math.BigDecimal includingTaxTotal) {
        this.includingTaxTotal = includingTaxTotal;
    }
    
}
